<?php
/**
 * @file
 * Google Analytics Linker plugin block
 */

class GoogleAnalyticsLinker extends BeanPlugin {

  /**
   * Declares default block settings.
   */
  public function values() {
    $values = parent::values();
    $values['domains'] = '';
    return $values;
  }

  /**
   * Builds extra settings for the block edit form.
   */
  public function form($bean, $form, &$form_state) {

    $form = array();

    $form['domains'] = array(
      '#type' => 'textfield',
      '#title' => t('Destination domain names for which Google Analytics will track clicks.'),
      '#description' => t("Comma-separated list of domains to track, documented at https://developers.google.com/analytics/devguides/collection/analyticsjs/linker"),
      '#required' => TRUE,
      '#default_value' => $bean->domains,
    );

    return $form;
  }

  /**
   * Displays the bean.
   */
  public function view($bean, $content, $view_mode = 'default', $langcode = NULL) {
    $domains = array();
    if ($bean->domains) {
      foreach (explode(',', $bean->domains) as $domain) {
        $domains[] = "'" . trim(check_plain($domain)) . "'";
      }
    }
    $domain_list = implode(',', $domains);
    $values = array(
      '#theme' => 'googleanalytics_linker',
      '#cache' => DRUPAL_CACHE_GLOBAL,
      'bean' => $content['bean'], // Needed by moriarty_preprocess_block
      'domains' => $domain_list,
    );
    return $values;
  }
}
